@@ -2,20 +2,17 @@ from abc import abstractmethod, ABCMeta
 from collections import deque
 from collections.abc import KeysView, MutableMapping
 from types import MappingProxyType
-from typing import Any, Deque, Iterator, Type
+from typing import Any, Deque, Iterator, Type, Optional, List
 
 from itemadapter.utils import (
     _get_pydantic_model_metadata,
-    _get_scrapy_item_classes,
     _is_attrs_class,
     _is_dataclass,
     _is_pydantic_model,
-    is_attrs_instance,
-    is_dataclass_instance,
-    is_pydantic_instance,
-    is_scrapy_item,
 )
 
+from itemadapter._imports import attr, dataclasses, _scrapy_item_classes
+
 
 __all__ = [
     "AdapterInterface",
@@ -54,6 +51,12 @@ class AdapterInterface(MutableMapping, metaclass=ABCMeta):
     def get_field_meta_from_class(cls, item_class: type, field_name: str) -> MappingProxyType:
         return MappingProxyType({})
 
+    @classmethod
+    def get_field_names_from_class(cls, item_class: type) -> Optional[List[str]]:
+        """Return a list of fields defined for ``item_class``.
+        If a class doesn't support fields, None is returned."""
+        return None
+
     def get_field_meta(self, field_name: str) -> MappingProxyType:
         """Return metadata for the given field name, if available."""
         return self.get_field_meta_from_class(self.item.__class__, field_name)
@@ -104,14 +107,14 @@ class _MixinAttrsDataclassAdapter:
 class AttrsAdapter(_MixinAttrsDataclassAdapter, AdapterInterface):
     def __init__(self, item: Any) -> None:
         super().__init__(item)
-        import attr
-
+        if attr is None:
+            raise RuntimeError("attr module is not available")
         # store a reference to the item's fields to avoid O(n) lookups and O(n^2) traversals
         self._fields_dict = attr.fields_dict(self.item.__class__)
 
     @classmethod
     def is_item(cls, item: Any) -> bool:
-        return is_attrs_instance(item)
+        return _is_attrs_class(item) and not isinstance(item, type)
 
     @classmethod
     def is_item_class(cls, item_class: type) -> bool:
@@ -119,25 +122,31 @@ class AttrsAdapter(_MixinAttrsDataclassAdapter, AdapterInterface):
 
     @classmethod
     def get_field_meta_from_class(cls, item_class: type, field_name: str) -> MappingProxyType:
-        from attr import fields_dict
-
+        if attr is None:
+            raise RuntimeError("attr module is not available")
         try:
-            return fields_dict(item_class)[field_name].metadata  # type: ignore
+            return attr.fields_dict(item_class)[field_name].metadata  # type: ignore
         except KeyError:
             raise KeyError(f"{item_class.__name__} does not support field: {field_name}")
 
+    @classmethod
+    def get_field_names_from_class(cls, item_class: type) -> Optional[List[str]]:
+        if attr is None:
+            raise RuntimeError("attr module is not available")
+        return [a.name for a in attr.fields(item_class)]
+
 
 class DataclassAdapter(_MixinAttrsDataclassAdapter, AdapterInterface):
     def __init__(self, item: Any) -> None:
         super().__init__(item)
-        import dataclasses
-
+        if dataclasses is None:
+            raise RuntimeError("dataclasses module is not available")
         # store a reference to the item's fields to avoid O(n) lookups and O(n^2) traversals
         self._fields_dict = {field.name: field for field in dataclasses.fields(self.item)}
 
     @classmethod
     def is_item(cls, item: Any) -> bool:
-        return is_dataclass_instance(item)
+        return _is_dataclass(item) and not isinstance(item, type)
 
     @classmethod
     def is_item_class(cls, item_class: type) -> bool:
@@ -145,22 +154,24 @@ class DataclassAdapter(_MixinAttrsDataclassAdapter, AdapterInterface):
 
     @classmethod
     def get_field_meta_from_class(cls, item_class: type, field_name: str) -> MappingProxyType:
-        from dataclasses import fields
-
-        for field in fields(item_class):
+        if dataclasses is None:
+            raise RuntimeError("dataclasses module is not available")
+        for field in dataclasses.fields(item_class):
             if field.name == field_name:
                 return field.metadata  # type: ignore
         raise KeyError(f"{item_class.__name__} does not support field: {field_name}")
 
+    @classmethod
+    def get_field_names_from_class(cls, item_class: type) -> Optional[List[str]]:
+        if dataclasses is None:
+            raise RuntimeError("dataclasses module is not available")
+        return [a.name for a in dataclasses.fields(item_class)]
+
 
 class PydanticAdapter(AdapterInterface):
 
     item: Any
 
-    @classmethod
-    def is_item(cls, item: Any) -> bool:
-        return is_pydantic_instance(item)
-
     @classmethod
     def is_item_class(cls, item_class: type) -> bool:
         return _is_pydantic_model(item_class)
@@ -172,6 +183,10 @@ class PydanticAdapter(AdapterInterface):
         except KeyError:
             raise KeyError(f"{item_class.__name__} does not support field: {field_name}")
 
+    @classmethod
+    def get_field_names_from_class(cls, item_class: type) -> Optional[List[str]]:
+        return list(item_class.__fields__.keys())  # type: ignore[attr-defined]
+
     def field_names(self) -> KeysView:
         return KeysView(self.item.__fields__)
 
@@ -224,6 +239,10 @@ class _MixinDictScrapyItemAdapter:
 
 
 class DictAdapter(_MixinDictScrapyItemAdapter, AdapterInterface):
+    @classmethod
+    def is_item(cls, item: Any) -> bool:
+        return isinstance(item, dict)
+
     @classmethod
     def is_item_class(cls, item_class: type) -> bool:
         return issubclass(item_class, dict)
@@ -235,15 +254,19 @@ class DictAdapter(_MixinDictScrapyItemAdapter, AdapterInterface):
 class ScrapyItemAdapter(_MixinDictScrapyItemAdapter, AdapterInterface):
     @classmethod
     def is_item(cls, item: Any) -> bool:
-        return is_scrapy_item(item)
+        return isinstance(item, _scrapy_item_classes)
 
     @classmethod
     def is_item_class(cls, item_class: type) -> bool:
-        return issubclass(item_class, _get_scrapy_item_classes())
+        return issubclass(item_class, _scrapy_item_classes)
 
     @classmethod
     def get_field_meta_from_class(cls, item_class: type, field_name: str) -> MappingProxyType:
-        return MappingProxyType(item_class.fields[field_name])  # type: ignore
+        return MappingProxyType(item_class.fields[field_name])  # type: ignore[attr-defined]
+
+    @classmethod
+    def get_field_names_from_class(cls, item_class: type) -> Optional[List[str]]:
+        return list(item_class.fields.keys())  # type: ignore[attr-defined]
 
     def field_names(self) -> KeysView:
         return KeysView(self.item.fields)
@@ -274,20 +297,34 @@ class ItemAdapter(MutableMapping):
 
     @classmethod
     def is_item(cls, item: Any) -> bool:
-        return any(adapter_class.is_item(item) for adapter_class in cls.ADAPTER_CLASSES)
+        for adapter_class in cls.ADAPTER_CLASSES:
+            if adapter_class.is_item(item):
+                return True
+        return False
 
     @classmethod
     def is_item_class(cls, item_class: type) -> bool:
-        return any(
-            adapter_class.is_item_class(item_class) for adapter_class in cls.ADAPTER_CLASSES
-        )
+        for adapter_class in cls.ADAPTER_CLASSES:
+            if adapter_class.is_item_class(item_class):
+                return True
+        return False
+
+    @classmethod
+    def _get_adapter_class(cls, item_class: type) -> Type[AdapterInterface]:
+        for adapter_class in cls.ADAPTER_CLASSES:
+            if adapter_class.is_item_class(item_class):
+                return adapter_class
+        raise TypeError(f"{item_class} is not a valid item class")
 
     @classmethod
     def get_field_meta_from_class(cls, item_class: type, field_name: str) -> MappingProxyType:
-        for adapter_class in cls.ADAPTER_CLASSES:
-            if adapter_class.is_item_class(item_class):
-                return adapter_class.get_field_meta_from_class(item_class, field_name)
-        raise TypeError(f"{item_class} is not a valid item class")
+        adapter_class = cls._get_adapter_class(item_class)
+        return adapter_class.get_field_meta_from_class(item_class, field_name)
+
+    @classmethod
+    def get_field_names_from_class(cls, item_class: type) -> Optional[List[str]]:
+        adapter_class = cls._get_adapter_class(item_class)
+        return adapter_class.get_field_names_from_class(item_class)
 
     @property
     def item(self) -> Any:
@@ -295,7 +332,7 @@ class ItemAdapter(MutableMapping):
 
     def __repr__(self) -> str:
         values = ", ".join([f"{key}={value!r}" for key, value in self.items()])
-        return f"<ItemAdapter for {self.item.__class__.__name__}({values})>"
+        return f"<{self.__class__.__name__} for {self.item.__class__.__name__}({values})>"
 
     def __getitem__(self, field_name: str) -> Any:
         return self.adapter.__getitem__(field_name)
@@ -321,8 +358,8 @@ class ItemAdapter(MutableMapping):
         return self.adapter.field_names()
 
     def asdict(self) -> dict:
-        """Return a dict object with the contents of the adapter. This works slightly different than
-        calling `dict(adapter)`: it's applied recursively to nested items (if there are any).
+        """Return a dict object with the contents of the adapter. This works slightly different
+        than calling `dict(adapter)`: it's applied recursively to nested items (if there are any).
         """
         return {key: _asdict(value) for key, value in self.items()}
 
@@ -331,11 +368,10 @@ def _asdict(obj: Any) -> Any:
     """Helper for ItemAdapter.asdict()."""
     if isinstance(obj, dict):
         return {key: _asdict(value) for key, value in obj.items()}
-    elif isinstance(obj, (list, set, tuple)):
+    if isinstance(obj, (list, set, tuple)):
         return obj.__class__(_asdict(x) for x in obj)
-    elif isinstance(obj, ItemAdapter):
+    if isinstance(obj, ItemAdapter):
         return obj.asdict()
-    elif ItemAdapter.is_item(obj):
+    if ItemAdapter.is_item(obj):
         return ItemAdapter(obj).asdict()
-    else:
-        return obj
+    return obj
